@@ -24,6 +24,18 @@
 namespace Oxygen
 {
 
+
+    //____________________________________________________________________
+    TreeViewEngine::TreeViewEngine( Animations* parent ):
+        GenericEngine<TreeViewData>( parent ),
+        _cursorLoaded( false ),
+        _cursor( 0L )
+    {}
+
+    //____________________________________________________________________
+    TreeViewEngine::~TreeViewEngine( void )
+    { if( _cursor ) gdk_cursor_unref( _cursor ); }
+
     //____________________________________________________________________
     bool TreeViewEngine::registerWidget( GtkWidget* widget )
     {
@@ -44,6 +56,18 @@ namespace Oxygen
                 !Gtk::gtk_parent_is_shadow_in( parent ) )
             { gtk_scrolled_window_set_shadow_type( scrolledWindow, GTK_SHADOW_IN ); }
 
+            // load cursor if needed
+            if( !_cursorLoaded )
+            {
+                assert( !_cursor );
+                GdkDisplay *display( gdk_display_get_default () );
+                _cursor = gdk_cursor_new_from_name( display, "row-resize" );
+                _cursorLoaded = true;
+            }
+
+            // pass cursor to data
+            data().value( widget ).setCursor( _cursor );
+
         }
 
         return true;
